==> mesa-7.4.4-i486-1sys.tgz: install/doinst.sh <==
#
( cd usr/lib ; rm -rf libGLw.so.1.0 )
( cd usr/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1.0 )
( cd usr/lib ; rm -rf libGLU.so )
( cd usr/lib ; ln -sf libGLU.so.1 libGLU.so )
( cd usr/lib ; rm -rf libGLU.so.1.3 )
( cd usr/lib ; ln -sf libGLU.so.1.3.070404 libGLU.so.1.3 )
( cd usr/lib ; rm -rf libglut.so.3.7 )
( cd usr/lib ; ln -sf libglut.so.3.7.1 libglut.so.3.7 )
( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
( cd usr/lib ; rm -rf libGLU.so.1 )
( cd usr/lib ; ln -sf libGLU.so.1.3.070404 libGLU.so.1 )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf libGL.so.1 libGL.so )
( cd usr/lib ; rm -rf libglut.so )
( cd usr/lib ; ln -sf libglut.so.3 libglut.so )
( cd usr/lib ; rm -rf libGLw.so.1 )
( cd usr/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
( cd usr/lib ; rm -rf libglut.so.3 )
( cd usr/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
( cd usr/lib ; rm -rf libGLw.so )
( cd usr/lib ; ln -sf libGLw.so.1 libGLw.so )
( cd usr/bin ; rm -rf glxpixmap )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxpixmap glxpixmap )
( cd usr/bin ; rm -rf glxswapcontrol )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxswapcontrol glxswapcontrol )
( cd usr/bin ; rm -rf glxgears_pixmap )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxgears_pixmap glxgears_pixmap )
( cd usr/bin ; rm -rf glsync )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glsync glsync )
( cd usr/bin ; rm -rf glxgears_fbconfig )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxgears_fbconfig glxgears_fbconfig )
( cd usr/bin ; rm -rf glxgears )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxgears glxgears )
( cd usr/bin ; rm -rf glxheads )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxheads glxheads )
( cd usr/bin ; rm -rf glxcontexts )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxcontexts glxcontexts )
( cd usr/bin ; rm -rf glxsnoop )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxsnoop glxsnoop )
( cd usr/bin ; rm -rf glxinfo )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxinfo glxinfo )
( cd usr/bin ; rm -rf glxdemo )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxdemo glxdemo )
( cd usr/bin ; rm -rf glthreads )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glthreads glthreads )
( cd usr/bin ; rm -rf glxpbdemo )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxpbdemo glxpbdemo )

==> mesa-7.5-i486-1sys.tgz: install/doinst.sh <==
#
( cd usr/lib ; rm -rf libGLU.so )
( cd usr/lib ; ln -sf libGLU.so.1 libGLU.so )
( cd usr/lib ; rm -rf libGL.so.1 )
( cd usr/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
( cd usr/lib ; rm -rf libGLU.so.1 )
( cd usr/lib ; ln -sf libGLU.so.1.3.070500 libGLU.so.1 )
( cd usr/lib ; rm -rf libEGL.so.1 )
( cd usr/lib ; ln -sf libEGL.so.1.0 libEGL.so.1 )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf libGL.so.1 libGL.so )
( cd usr/lib ; rm -rf libglut.so )
( cd usr/lib ; ln -sf libglut.so.3 libglut.so )
( cd usr/lib ; rm -rf libGLw.so.1 )
( cd usr/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
( cd usr/lib ; rm -rf libEGL.so )
( cd usr/lib ; ln -sf libEGL.so.1 libEGL.so )
( cd usr/lib ; rm -rf libglut.so.3 )
( cd usr/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
( cd usr/lib ; rm -rf libGLw.so )
( cd usr/lib ; ln -sf libGLw.so.1 libGLw.so )
( cd usr/bin ; rm -rf glxpixmap )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxpixmap glxpixmap )
( cd usr/bin ; rm -rf glxswapcontrol )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxswapcontrol glxswapcontrol )
( cd usr/bin ; rm -rf glxgears_pixmap )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxgears_pixmap glxgears_pixmap )
( cd usr/bin ; rm -rf glsync )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glsync glsync )
( cd usr/bin ; rm -rf glxgears_fbconfig )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxgears_fbconfig glxgears_fbconfig )
( cd usr/bin ; rm -rf glxgears )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxgears glxgears )
( cd usr/bin ; rm -rf glxheads )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxheads glxheads )
( cd usr/bin ; rm -rf glxcontexts )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxcontexts glxcontexts )
( cd usr/bin ; rm -rf glxsnoop )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxsnoop glxsnoop )
( cd usr/bin ; rm -rf glxinfo )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxinfo glxinfo )
( cd usr/bin ; rm -rf glxdemo )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxdemo glxdemo )
( cd usr/bin ; rm -rf glthreads )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glthreads glthreads )
( cd usr/bin ; rm -rf glxpbdemo )
( cd usr/bin ; ln -sf /usr/share/mesa3d/bin/xdemos/glxpbdemo glxpbdemo )
